import { GraphQLObjectType, GraphQLObjectTypeConfig, GraphQLFieldConfig, GraphQLField } from 'graphql/type';
import { GraphQLDirectiveValue } from './directives';
export interface GraphQLObjectTypeConfigExt<TSource, TContext> extends GraphQLObjectTypeConfig<TSource, TContext> {
    directives?: Thunk<Array<GraphQLDirectiveValue>>;
    [prop: string]: mixed;
}
export interface GraphQLFieldConfigMapExt<TSource, TContext> {
    [fieldName: string]: GraphQLFieldConfigExt<TSource, TContext>;
}
export interface GraphQLFieldConfigExt<TSource, TContext> extends GraphQLFieldConfig<TSource, TContext> {
    directives: Array<GraphQLDirectiveValue>;
    [prop: string]: mixed;
}
export interface GraphQLFieldExt<TSource, TContext> extends GraphQLField<TSource, TContext> {
    directives: Array<GraphQLDirectiveValue>;
}
/**
 * The schemata is an extension of a GraphQLSchema that includes extra
 * functionality to merge schemas, manage directives, and more.
 *
 * Schemata Definition
 *
 * A Schema is created by supplying the root types of each type of operation,
 * query and mutation (optional). A schema definition is then supplied to the
 * validator and executor.
 *
 * Example:
 *
 *     const MyAppSchema = new GraphQLSchema({
 *       query: MyAppQueryRootType,
 *       mutation: MyAppMutationRootType,
 *     })
 *
 * Note: If an array of `directives` are provided to GraphQLSchema, that will be
 * the exact list of directives represented and allowed. If `directives` is not
 * provided then a default set of the specified directives (e.g. @include and
 * @skip) will be used. If you wish to provide *additional* directives to these
 * specified directives, you must explicitly declare them. Example:
 *
 *     const MyAppSchema = new GraphQLSchema({
 *       ...
 *       directives: specifiedDecorators.concat([ myCustomDirective ]),
 *     })
 *
 */
export declare class GraphQLObjectTypeExt extends GraphQLObjectType {
    private _typeConfig;
    private _directives;
    constructor(config: GraphQLObjectTypeConfigExt<mixed, mixed>);
    readonly config: GraphQLObjectTypeConfigExt<mixed, mixed>;
    getDirectives(): Array<GraphQLDirectiveValue>;
    extendConfig(extra?: Object): void;
}
