import { Source } from 'graphql/language/source';
import { Location, DocumentNode, DirectiveNode } from 'graphql/language/ast';
import { GraphQLSchema } from 'graphql/type/schema';
import { TypeResolverMap } from './ResolverMap';
/**
 * This takes the ast of a schema document produced by the parse function in
 * src/language/parser.js.
 *
 * If no schema definition is provided, then it will look for types named Query
 * and Mutation.
 *
 * Given that AST it constructs a GraphQLSchema. The resulting schema
 * has no resolve methods, so execution will use default resolvers.
 */
export declare function buildASTSchema(ast: DocumentNode, resolverMap?: TypeResolverMap<mixed, mixed>): GraphQLSchema;
/**
 * Given a collection of directives, returns the string value for the
 * deprecation reason.
 */
export declare function getDeprecationReason(directives?: Array<DirectiveNode>): string | undefined;
/**
 * Given an ast node, returns its string description based on a contiguous
 * block full-line of comments preceding it.
 */
export declare function getDescription(node: {
    loc?: Location;
}): string | undefined;
/**
 * A helper function to build a GraphQLSchema directly from a source
 * document.
 */
export declare function buildSchema(source: string | Source): GraphQLSchema;
